@@ -8,7 +8,6 @@ const {Suite, Runner, Test, Hook, Runnable} = Mocha;
 const {noop} = Mocha.utils;
 const {FATAL, MULTIPLE_DONE, UNSUPPORTED} =
   require('../../lib/errors').constants;
-const errors = require('../../lib/errors');
 
 const {
   EVENT_HOOK_BEGIN,
@@ -30,15 +29,6 @@ describe('Runner', function () {
     sinon.restore();
   });
 
-  describe('constructor deprecation', function () {
-    it('should print a deprecation warning', function () {
-      sinon.stub(errors, 'deprecate');
-      const suite = new Suite('Suite', 'root');
-      new Runner(suite, false); /* eslint no-new: "off" */
-      expect(errors.deprecate, 'was called once');
-    });
-  });
-
   describe('instance method', function () {
     let suite;
     let runner;
